==> s-loc-instance-5.0.16.tgz: package/setup.js <==
let Run = require('./scripts/run');
module.exports = function (params, next, worker, processes, failed) {

    let _cluster = require('cluster');
    console.log('clustering');
    Run(next).then(function () {
        if (_cluster.isMaster) {
            console.log('setup2')
            params(function (parameters) {
                console.lgo(parameters, 'are params')
                let cpus = (parameters.processCount) ? parameters.processCount:require('os').cpus().length;
                console.log('Forking S_Loc_Instance Version', require('./package.json').version, "on", cpus, 'count(s)');
                for (let i = 0; i < cpus; i++) {
                    let workerP = _cluster.fork();
                    if (worker) {
                        workerP.on('message', function (message) {
                            worker(_cluster, workerP.id, message);
                        });
                    }
                }
            })
        } else {
            console.log('process');
            if (processes) {
                processes(_cluster.worker.id, params.processCount)
            }
        }
    }).catch((failed) ? failed : processes);/*
    if (params._cluster.isMaster) {
        let cpus = (params.processCount) ? params.processCount:require('os').cpus().length;
        console.log('Forking S_Loc_Instance Version', require('./package.json').version);
        for (let i = 0; i < cpus; i++) {
            let workerP = _this.cluster.fork();
            if (worker) {
                workerP.on('message', function (message) {
                    worker(_this, workerP.id, message);
                });
            }
        }
    }
    Run(next).then(function () {
        if (!params.cluster._cluster.isMaster) {
            console.log('setup')
            params(function (parameters) {
                _this.cpus = (parameters.processCount) ? params.processCount:require('os').cpus().length;
                console.log('Forking S_Loc_Instance Version', require('./package.json').version);
                for (let i = 0; i < cpus; i++) {
                    let workerP = _this.cluster.fork();
                    if (worker) {
                        workerP.on('message', function (message) {
                            worker(_this, workerP.id, message);
                        });
                    }
                }
            })
        } else {
            if (processes) {
                processes(_this.cluster._cluster.worker.id, params.processCount)
            }
        }
    }).catch((failed) ? failed : processes);*/
}

==> s-loc-instance-5.0.17.tgz: package/setup.js <==
let Run = require('./scripts/run');
module.exports = function (params, next, worker, processes, failed) {

    let _cluster = require('cluster');
    console.log('clustering');
    Run(next).then(function () {
        if (_cluster.isMaster) {
            console.log('setup2')
            params(function (parameters) {
                console.log(parameters, 'are params')
                let cpus = (parameters.processCount) ? parameters.processCount:require('os').cpus().length;
                console.log('Forking S_Loc_Instance Version', require('./package.json').version, "on", cpus, 'count(s)');
                for (let i = 0; i < cpus; i++) {
                    let workerP = _cluster.fork();
                    if (worker) {
                        workerP.on('message', function (message) {
                            worker(_cluster, workerP.id, message);
                        });
                    }
                }
            })
        } else {
            console.log('process');
            if (processes) {
                processes(_cluster.worker.id, params.processCount)
            }
        }
    }).catch((failed) ? failed : processes);/*
    if (params._cluster.isMaster) {
        let cpus = (params.processCount) ? params.processCount:require('os').cpus().length;
        console.log('Forking S_Loc_Instance Version', require('./package.json').version);
        for (let i = 0; i < cpus; i++) {
            let workerP = _this.cluster.fork();
            if (worker) {
                workerP.on('message', function (message) {
                    worker(_this, workerP.id, message);
                });
            }
        }
    }
    Run(next).then(function () {
        if (!params.cluster._cluster.isMaster) {
            console.log('setup')
            params(function (parameters) {
                _this.cpus = (parameters.processCount) ? params.processCount:require('os').cpus().length;
                console.log('Forking S_Loc_Instance Version', require('./package.json').version);
                for (let i = 0; i < cpus; i++) {
                    let workerP = _this.cluster.fork();
                    if (worker) {
                        workerP.on('message', function (message) {
                            worker(_this, workerP.id, message);
                        });
                    }
                }
            })
        } else {
            if (processes) {
                processes(_this.cluster._cluster.worker.id, params.processCount)
            }
        }
    }).catch((failed) ? failed : processes);*/
}
